@@ -1,14 +1,43 @@
-let AVAILABLE_LANGUAGES = ["c", "cpp", "py", "java"]
+TESTHELPER_NAMES = ["PASS()", "FAIL()", "RESULT(0-100)", "CHECK_STDOUT()"];
+
+const AVAILABLE_LANGUAGES = {
+    "c": "text/x-csrc",
+    "cpp": "text/x-c++src",
+    "py": "python",
+    "java": "text/x-java"
+}
+const MAX_TESTCASE_NAME_DISPLAY_LENGTH = 30;
+const CODE_PLACEHOLDER = `
+# Use PASS(), RESULT(0-100), FAIL(),
+# and CHECK_STDOUT() to instruct
+# autograder how to grade student's
+# submission
+
+def main():
+    r = student_submission.any_function()
+
+    EXPECTED_RESULT = 83
+    if r == EXPECTED_RESULT:
+        PASS()
+    else:
+        FAIL()
+
+
+main()`.trim();
 // $(document).ready(function () {
 //     window.resizeTo(1200, 900);
 // });
 
 
-function getTestcaseLanguageImage(name) {
+function getSuffix(name) {
     let splitName = name.split(".");
     let suffix = splitName.length > 1 ? splitName[splitName.length - 1] : "";
-    suffix = suffix.toLowerCase();
-    if (AVAILABLE_LANGUAGES.includes(suffix))
+    return suffix.toLowerCase();
+}
+
+function getTestcaseLanguageImage(name) {
+    let suffix = getSuffix(name);
+    if (AVAILABLE_LANGUAGES.hasOwnProperty(suffix))
         imgstem = suffix;
     else
         imgstem = "gear";
@@ -16,8 +45,8 @@ function getTestcaseLanguageImage(name) {
 }
 
 function getTestcaseDisplayName(name) {
-    if (name.length >= 28)
-        return name.substring(0, 25) + "...";
+    if (name.length > MAX_TESTCASE_NAME_DISPLAY_LENGTH)
+        return name.substring(0, MAX_TESTCASE_NAME_DISPLAY_LENGTH) + "...";
     else
         return name
 }
